#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2018-03-13
#
# Check Point VSX status metrics plugin
# checkpoint_vsx
#
from cmk.gui.i18n import _

from cmk.gui.plugins.metrics import (
    metric_info,
    graph_info,
    perfometer_info,
    check_metrics,
)

metric_info['checkpoint_vsx_connections'] = {
    'title': _('Connections active'),
    'unit': 'count',
    'color': '26/a',
}
metric_info['checkpoint_vsx_connections_peak'] = {
    'title': _('Connections peak'),
    'unit': 'count',
    'color': '21/a',
}
metric_info['checkpoint_vsx_connections_limit'] = {
    'title': _('Connections limit'),
    'unit': 'count',
    'color': '31/a',
}

metric_info['checkpoint_vsx_packets_processed'] = {
    'title': _('Packets processed'),
    'unit': '1/s',
    'color': '12/a',
}
metric_info['checkpoint_vsx_packets_dropped'] = {
    'title': _('Packets dropped'),
    'unit': '1/s',
    'color': '22/a',
}
metric_info['checkpoint_vsx_packets_accepted'] = {
    'title': _('Packets accepted'),
    'unit': '1/s',
    'color': '32/a',
}
metric_info['checkpoint_vsx_packets_rejected'] = {
    'title': _('Packets rejected'),
    'unit': '1/s',
    'color': '42/a',
}

metric_info['checkpoint_vsx_bytes_accepted'] = {
    'title': _('Bytes accepted'),
    'unit': 'bytes/s',
    'color': '13/a',
}
metric_info['checkpoint_vsx_bytes_dropped'] = {
    'title': _('Bytes dropped'),
    'unit': 'bytes/s',
    'color': '23/a',
}
metric_info['checkpoint_vsx_bytes_rejected'] = {
    'title': _('Bytes rejected'),
    'unit': 'bytes/s',
    'color': '33/a',
}

metric_info['checkpoint_vsx_loggs_send'] = {
    'title': _('Loggs send'),
    'unit': '1/s',
    'color': '14/a',
}

check_metrics['check_mk-checkpoint_vsx_system'] = {
    'checkpoint_vsx_connections_peak':  {'auto_graph': False},
    'checkpoint_vsx_connections_limit':  {'auto_graph': False},
}

graph_info['checkpoint_vsx_connections'] = {
    'title': _('Check Point VSX: Connections'),
    'metrics': [
        ('checkpoint_vsx_connections', 'area'),
    ],
    'scalars': [
        ('checkpoint_vsx_connections:crit', _('crit')),
        ('checkpoint_vsx_connections:warn', _('warn')),
        ('checkpoint_vsx_connections_limit', _('limit')),
        ('checkpoint_vsx_connections_peak', _('peak')),
    ],
}

graph_info['checkpoint_vsx_packets'] = {
    'title': _('Check Point VSX: Packets'),
    'metrics': [
        ('checkpoint_vsx_packets_rejected', 'stack'),
        ('checkpoint_vsx_packets_dropped', 'stack'),
        ('checkpoint_vsx_packets_accepted', 'stack'),
        ('checkpoint_vsx_packets_processed', 'line'),
    ]
}

graph_info['checkpoint_vsx_bytes'] = {
    'title': _('Check Point VSX: Bytes'),
    'metrics': [
        ('checkpoint_vsx_bytes_rejected', 'line'),
        ('checkpoint_vsx_bytes_dropped', 'line'),
        ('checkpoint_vsx_bytes_accepted', 'line'),
    ]
}

graph_info['checkpoint_vsx_loggs_send'] = {
    'title': _('Check Point VSX: Logs'),
    'metrics': [
        ('checkpoint_vsx_loggs_send', 'area'),
    ]
}

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_vsx_connections',
        'half_value': 50000.0,
        'exponent': 2,
    },
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_vsx_packets_processed',
        'half_value': 50000.0,
        'exponent': 2,
    },
]))
